/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2022  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#include "../lib/graphic.h"

#define NUM 101

int main(int argc, char const *argv[])
{
	gctl::array<double> x(NUM), y(NUM), z(NUM*NUM);
    x.sequence(-2.0*GCTL_Pi, 0.04*GCTL_Pi);
    y.sequence(-2.0*GCTL_Pi, 0.04*GCTL_Pi);

    for (size_t i = 0; i < NUM; i++)
    {
        for (size_t j = 0; j < NUM; j++)
        {
            z[j + i*NUM] = sin(sqrt(x[j]*x[j] + y[i]*y[i]));
        }
    }
    
    gctl::mathgl_dens plt;
    plt.range(-2.0*GCTL_Pi, 2.0*GCTL_Pi, -2.0*GCTL_Pi, 2.0*GCTL_Pi);
    plt.demension(NUM, NUM);
    plt.add_dens(z, "sin");
    plt.plot();

	return 0;
}
