/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2022  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#ifndef _GCTL_mathgl_dens_H
#define _GCTL_mathgl_dens_H

#include "gctl_graphic_config.h"

#ifdef GCTL_GRAPHIC_MATHGL

#include "gctl/core.h"
#include "gctl/maths.h"
#include "gctl/algorithms.h"

#include "mgl2/mgl.h"
#include "mgl2/fltk.h"

namespace gctl
{
    class mathgl_dens : public mglDraw
    {
    public:
        mathgl_dens();
        virtual ~mathgl_dens();

        void range(double xmin, double xmax, double ymin, double ymax);
        void demension(int xnum, int ynum);
        void xlabel(std::string xname);
        void ylabel(std::string yname);
        void add_dens(const array<double> &in_z, std::string z_label = "null");
        int plot();

        int Draw(mglGraph *gr);

    protected:
        int xnum_, ynum_;
        double xmin_, xmax_, ymin_, ymax_;
        std::string x_ll_, y_ll_, z_ll_;
        array<double> z_;
    };
}

#endif // GCTL_SEISMIC_MATHGL

#endif // _GCTL_mathgl_dens_H